@@ -29,7 +29,6 @@
 #include "va_trace.h"
 #include "va_fool.h"
 #include "va_x11.h"
-#include "va_dri.h"
 #include "va_dri2.h"
 #include "va_dricommon.h"
 #include "va_nvctrl.h"
@@ -63,12 +62,12 @@ static void va_DisplayContextDestroy (
         return;
 
     ctx = pDisplayContext->pDriverContext;
-    dri_state = ctx->dri_state;
+    dri_state = ctx->drm_state;
 
     if (dri_state && dri_state->close)
         dri_state->close(ctx);
 
-    free(pDisplayContext->pDriverContext->dri_state);
+    free(pDisplayContext->pDriverContext->drm_state);
     free(pDisplayContext->pDriverContext);
     free(pDisplayContext);
 }
@@ -87,19 +86,6 @@ static VAStatus va_DRI2GetDriverName (
     return VA_STATUS_SUCCESS;
 }
 
-static VAStatus va_DRIGetDriverName (
-    VADisplayContextP pDisplayContext,
-    char **driver_name
-)
-{
-    VADriverContextP ctx = pDisplayContext->pDriverContext;
-
-    if (!isDRI1Connected(ctx, driver_name))
-        return VA_STATUS_ERROR_UNKNOWN;
-
-    return VA_STATUS_SUCCESS;
-}
-
 static VAStatus va_NVCTRL_GetDriverName (
     VADisplayContextP pDisplayContext,
     char **driver_name
@@ -152,8 +138,6 @@ static VAStatus va_DisplayContextGetDriverName (
 	*driver_name = NULL;
 
     vaStatus = va_DRI2GetDriverName(pDisplayContext, driver_name);
-    if (vaStatus != VA_STATUS_SUCCESS)
-        vaStatus = va_DRIGetDriverName(pDisplayContext, driver_name);
     if (vaStatus != VA_STATUS_SUCCESS)
         vaStatus = va_NVCTRL_GetDriverName(pDisplayContext, driver_name);
     if (vaStatus != VA_STATUS_SUCCESS)
@@ -185,12 +169,13 @@ VADisplay vaGetDisplay (
 	  pDisplayContext->vadpy_magic = VA_DISPLAY_MAGIC;          
 
 	  pDriverContext->native_dpy       = (void *)native_dpy;
+          pDriverContext->display_type     = VA_DISPLAY_X11;
 	  pDisplayContext->pDriverContext  = pDriverContext;
 	  pDisplayContext->vaIsValid       = va_DisplayContextIsValid;
 	  pDisplayContext->vaDestroy       = va_DisplayContextDestroy;
 	  pDisplayContext->vaGetDriverName = va_DisplayContextGetDriverName;
           pDisplayContext->opaque          = NULL;
-	  pDriverContext->dri_state 	   = dri_state;
+	  pDriverContext->drm_state 	   = dri_state;
 	  dpy                              = (VADisplay)pDisplayContext;
       }
       else
